# irony

![piron](assets/irony.svg)

 IRaf pythON photometrY  (`irony`) is a package designed for astronomers to do photometry.

## Installation

```shell
pip install irony
```

## Examples
- [Fits](examples/001-fits.ipynb)
- [FitsArray](examples/002-fits_array.ipynb)
- [Calibration](examples/003-calibration.ipynb)
- [Align](examples/004-align.ipynb)
- [Photometry](examples/005-phot.ipynb)

## License

GNU-GPL V3

## Author
Mohammad S.Niaei

m.shemuni@gmail.com